@@ -2,7 +2,11 @@
 
 __author__ = """Yossi Mosbacher"""
 __email__ = 'joe.mosbacher@gmail.com'
-__version__ = '0.4.2'
+__version__ = '0.4.6'
+
+# import eve_panel
+from . import api
+from .api.app import list_roles
 
 def settings(**kwargs):
     from eve_panel import settings as panel_settings
@@ -16,7 +20,8 @@ def default_client():
     from xepmts.api.client import default_client
     return default_client()
 
-def notebook():
-    import panel as pn
-    return pn.extension()
+def extension():
+    import eve_panel
+    eve_panel.extension()
 
+notebook = extension
\ No newline at end of file
