@@ -1,5 +1,5 @@
 import eve_panel
-from xepmts.api import app
+from .app import make_local_app
 import os
 import pkg_resources
 
@@ -9,6 +9,8 @@ APPS = {
     in pkg_resources.iter_entry_points('xepmts.apps')
 }
 
+APPS["db"] =  make_local_app
+
 def make_client(app_names=None):
     if app_names is None:
         app_names = list(APPS)
